@@ -1,9 +1,10 @@
+pub use aoko::no_std::algebraic::sum::TimeUnit;
 use clap::Parser;
 
 /// Batch processing word-count, support English & Chinese.
 
 #[derive(Parser)]
-#[clap(version = "0.1.1", author = "hzqd <hzqelf@yeah.net>")]
+#[clap(version = "0.1.3", author = "hzqd <hzqelf@yeah.net>")]
 pub struct Args {
     /// Specify the dictionary name, no dictionary by default
     #[clap(short, long, default_value = "")]
@@ -19,14 +20,13 @@ pub struct Args {
 
     /// Specify the time unit, support nanos, micros, millis, secs
     #[clap(short, long, default_value = "millis")]
-    pub time: String,
+    pub time: TimeUnit,
 
     /// Set language, support English(en) and Chinese(cn)
     #[clap(subcommand)]
     pub subcmd: Lang,
 }
 
-
 #[derive(Parser)]
 pub enum Lang {
     /// A subcommand for specify English
